@@ -2,6 +2,12 @@
 # shellcheck disable=SC1091
 set -eu -o pipefail
 
+if [[ $UID -ne 0 ]]; then
+    sudo_cmd="sudo"
+else
+    sudo_cmd=""
+fi
+
 source /etc/os-release
 
 distro="$ID"
@@ -29,7 +35,8 @@ git archive --verbose --format=tar.gz --prefix="azure-vm-utils-${version}/" HEAD
 cd "${project_dir}/packaging/${distro}"
 
 # Install dependencies.
-sudo dnf builddep -y --spec azure-vm-utils.spec
+build_requirements=$(grep ^BuildRequires azure-vm-utils.spec | awk '{{print $2}}' | tr '\n' ' ')
+$sudo_cmd dnf install -y ${build_requirements} rpm-build dracut
 
 # Build RPM.
 rpmbuild -ba --define "__git_version ${version}" --define "__git_release ${release}" --define "_topdir ${build_dir}" azure-vm-utils.spec
@@ -37,4 +44,4 @@ rpmbuild -ba --define "__git_version ${version}" --define "__git_release ${relea
 # Copy RPM to output directory.
 mkdir -p "${output_dir}"
 rm -f "${output_dir}"/*.rpm
-cp -v "${build_dir}"/RPMS/*/"azure-vm-utils-${version}-${release}".*.rpm "${output_dir}"
+cp -v "${build_dir}"/RPMS/*/azure-vm-utils*"${version}-${release}"*.rpm "${output_dir}"
